@@ -38,6 +38,7 @@ class FakeServer:
         # Maps channel/pattern to weak set of sockets
         self.subscribers = defaultdict(weakref.WeakSet)
         self.psubscribers = defaultdict(weakref.WeakSet)
+        self.ssubscribers = defaultdict(weakref.WeakSet)
         self.lastsave = int(time.time())
         self.connected = True
         # List of weakrefs to sockets that are being closed lazily
@@ -64,7 +65,7 @@ class FakeBaseConnectionMixin:
             else:
                 host, port = kwargs.get('host'), kwargs.get('port')
                 self.server_key = f'{host}:{port}'
-            self.server_key += f'v{version}'
+            self.server_key += f':v{version}'
             self._server = FakeServer.get_server(self.server_key, version=version)
             self._server.connected = connected
         super().__init__(*args, **kwargs)
@@ -133,7 +134,7 @@ class FakeConnection(FakeBaseConnectionMixin, redis.Connection):
 
 
 class FakeRedisMixin:
-    def __init__(self, *args, server=None, connected=True, version=(7,), **kwargs):
+    def __init__(self, *args, server=None, version=(7,), **kwargs):
         # Interpret the positional and keyword arguments according to the
         # version of redis in use.
         parameters = list(inspect.signature(redis.Redis.__init__).parameters.values())[1:]
@@ -170,6 +171,7 @@ class FakeRedisMixin:
                 'max_connections',
                 'health_check_interval',
                 'client_name',
+                'connected',
             }
             connection_kwargs = {
                 'connection_class': FakeConnection,
