@@ -1,4 +1,4 @@
-from typing import Tuple, Any
+from typing import Tuple, Any, Dict
 
 from fakeredis import _msgs as msgs
 from fakeredis._commands import (command)
@@ -40,6 +40,13 @@ class PubSubCommandsMixin:
             self.put_response(msg)
         return NoResponse()
 
+    def _numsub(self, subscribers: Dict[bytes, Any], *channels):
+        tuples_list = [
+            (ch, len(subscribers.get(ch, [])))
+            for ch in channels
+        ]
+        return [item for sublist in tuples_list for item in sublist]
+
     @command((bytes,), (bytes,), flags=msgs.FLAG_NO_SCRIPT)
     def psubscribe(self, *patterns):
         return self._subscribe(patterns, self._server.psubscribers, b'psubscribe')
@@ -48,6 +55,10 @@ class PubSubCommandsMixin:
     def subscribe(self, *channels):
         return self._subscribe(channels, self._server.subscribers, b'subscribe')
 
+    @command((bytes,), (bytes,), flags=msgs.FLAG_NO_SCRIPT)
+    def ssubscribe(self, *channels):
+        return self._subscribe(channels, self._server.ssubscribers, b'ssubscribe')
+
     @command((), (bytes,), flags=msgs.FLAG_NO_SCRIPT)
     def punsubscribe(self, *patterns):
         return self._unsubscribe(patterns, self._server.psubscribers, b'punsubscribe')
@@ -56,6 +67,10 @@ class PubSubCommandsMixin:
     def unsubscribe(self, *channels):
         return self._unsubscribe(channels, self._server.subscribers, b'unsubscribe')
 
+    @command(fixed=(), repeat=(bytes,), flags=msgs.FLAG_NO_SCRIPT)
+    def sunsubscribe(self, *channels):
+        return self._unsubscribe(channels, self._server.ssubscribers, b'sunsubscribe')
+
     @command((bytes, bytes))
     def publish(self, channel, message):
         receivers = 0
@@ -73,22 +88,49 @@ class PubSubCommandsMixin:
                     receivers += 1
         return receivers
 
-    @command(name='PUBSUB CHANNELS', fixed=(), repeat=(bytes,))
-    def pubsub_channels(self, *args):
-        channels = list(self._server.subscribers.keys())
-        if len(args) > 0:
-            regex = compile_pattern(args[0])
+    @command((bytes, bytes))
+    def spublish(self, channel, message):
+        receivers = 0
+        msg = [b'smessage', channel, message]
+        subs = self._server.ssubscribers.get(channel, set())
+        for sock in subs:
+            sock.put_response(msg)
+            receivers += 1
+        for (pattern, socks) in self._server.psubscribers.items():
+            regex = compile_pattern(pattern)
+            if regex.match(channel):
+                msg = [b'pmessage', pattern, channel, message]
+                for sock in socks:
+                    sock.put_response(msg)
+                    receivers += 1
+        return receivers
+
+    @command(name='PUBSUB NUMPAT', fixed=(), repeat=())
+    def pubsub_numpat(self, *_):
+        return len(self._server.psubscribers)
+
+    def _channels(self, subscribers_dict: Dict[bytes, Any], *patterns):
+        channels = list(subscribers_dict.keys())
+        if len(patterns) > 0:
+            regex = compile_pattern(patterns[0])
             channels = [ch for ch in channels if regex.match(ch)]
         return channels
 
+    @command(name='PUBSUB CHANNELS', fixed=(), repeat=(bytes,))
+    def pubsub_channels(self, *args):
+        return self._channels(self._server.subscribers, *args)
+
+    @command(name='PUBSUB SHARDCHANNELS', fixed=(), repeat=(bytes,))
+    def pubsub_shardchannels(self, *args):
+        return self._channels(self._server.ssubscribers, *args)
+
     @command(name='PUBSUB NUMSUB', fixed=(), repeat=(bytes,))
     def pubsub_numsub(self, *args):
-        channels = args
-        tuples_list = [
-            (ch, len(self._server.subscribers.get(ch, [])))
-            for ch in channels
-        ]
-        return [item for sublist in tuples_list for item in sublist]
+        return self._numsub(self._server.subscribers, *args)
+
+    @command(name='PUBSUB SHARDNUMSUB', fixed=(), repeat=(bytes,))
+    def pubsub_shardnumsub(self, *args):
+        return self._numsub(self._server.ssubscribers, *args)
 
     @command(name='PUBSUB', fixed=())
     def pubsub(self, *args):
